window.Gleam.initSearch([{"doc":"glee","title":"glee","content":"# glee\n\nGlee is a simple way to parse JSON by taking in JSON and\nreturning a string.\n\nThis is my first package, i&#39;m new to gleam- I&#39;m sure there\nare things I could do better\n\n[![Package Version](https://img.shields.io/hexpm/v/glee)](https://hex.pm/packages/glee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glee/)\n\n```sh\ngleam add glee@2\n```\n\n## Decoding JSON\n\nGlee also provides functions to decode JSON into values:\n\nGetting a string:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30}&quot;\n  let result = glee.parse_json_string(json, &quot;name&quot;)\n  \n  case result {\n    Ok(name) -&gt; io.println(&quot;Name: &quot; &lt;&gt; name)\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\nGetting a float:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/float\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30.4}&quot;\n  let result = glee.parse_json_float(json, &quot;age&quot;)\n  \n  case result {\n    Ok(age) -&gt; io.println(&quot;Age: &quot; &lt;&gt; float.to_string(age))\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\nGetting an int:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/int\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30}&quot;\n  let result = glee.parse_json_int(json, &quot;age&quot;)\n  \n  case result {\n    Ok(age) -&gt; io.println(&quot;Age: &quot; &lt;&gt; int.to_string(age))\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\n## Encoding JSON\n\nGlee also provides functions to encode values into JSON:\n\n```gleam\nimport glee\nimport gleam/io\nimport gleam/dict\n\npub fn main() {\n  // Encode simple values\n  let string_json = glee.encode_string(&quot;hello&quot;)  // &quot;hello&quot;\n  let int_json = glee.encode_int(42)  // 42\n  let float_json = glee.encode_float(3.14)  // 3.14\n  let bool_json = glee.encode_bool(True)  // true\n  \n  // Create a simple JSON object\n  let person = glee.create_json_object(&quot;name&quot;, glee.encode_string(&quot;Alice&quot;))\n  io.println(person)  // {&quot;name&quot;:&quot;Alice&quot;}\n  \n  // Create a JSON object from multiple pairs\n  let pairs = [\n    #(&quot;name&quot;, glee.encode_string(&quot;Bob&quot;)),\n    #(&quot;age&quot;, glee.encode_int(30)),\n    #(&quot;active&quot;, glee.encode_bool(True))\n  ]\n  let complex_person = glee.create_json_object_from_pairs(pairs)\n  io.println(complex_person)  // {&quot;name&quot;:&quot;Bob&quot;,&quot;age&quot;:30,&quot;active&quot;:true}\n  \n  // Create a JSON array\n  let values = [\n    glee.encode_string(&quot;apple&quot;),\n    glee.encode_string(&quot;banana&quot;),\n    glee.encode_string(&quot;cherry&quot;)\n  ]\n  let fruits = glee.encode_list(values)\n  io.println(fruits)  // [&quot;apple&quot;,&quot;banana&quot;,&quot;cherry&quot;]\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glee&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glee","title":"create_json_object","content":"pub fn create_json_object(key: String, value: String) -&gt; String\n Create a simple JSON object with a single key-value pair\nSynonyms:\nglee.create_json_object\nglee create_json_object","url":"glee.html#create_json_object"},{"doc":"glee","title":"create_json_object_from_pairs","content":"pub fn create_json_object_from_pairs(\n  pairs: List(#(String, String)),\n) -&gt; String\n Create a JSON object from multiple key-value pairs\nSynonyms:\nglee.create_json_object_from_pairs\nglee create_json_object_from_pairs","url":"glee.html#create_json_object_from_pairs"},{"doc":"glee","title":"encode_bool","content":"pub fn encode_bool(value: Bool) -&gt; String\n Encode a boolean value into a JSON string\nSynonyms:\nglee.encode_bool\nglee encode_bool","url":"glee.html#encode_bool"},{"doc":"glee","title":"encode_float","content":"pub fn encode_float(value: Float) -&gt; String\n Encode a float value into a JSON string\nSynonyms:\nglee.encode_float\nglee encode_float","url":"glee.html#encode_float"},{"doc":"glee","title":"encode_int","content":"pub fn encode_int(value: Int) -&gt; String\n Encode an int value into a JSON string\nSynonyms:\nglee.encode_int\nglee encode_int","url":"glee.html#encode_int"},{"doc":"glee","title":"encode_list","content":"pub fn encode_list(values: List(String)) -&gt; String\n Encode a list of values into a JSON array string\nSynonyms:\nglee.encode_list\nglee encode_list","url":"glee.html#encode_list"},{"doc":"glee","title":"encode_object","content":"pub fn encode_object(values: Dict(String, String)) -&gt; String\n Encode a map of string keys and string values into a JSON object string\nSynonyms:\nglee.encode_object\nglee encode_object","url":"glee.html#encode_object"},{"doc":"glee","title":"encode_string","content":"pub fn encode_string(value: String) -&gt; String\n Encode a string value into a JSON string\nSynonyms:\nglee.encode_string\nglee encode_string","url":"glee.html#encode_string"},{"doc":"glee","title":"extract_value_from_json","content":"pub fn extract_value_from_json(\n  json: String,\n  parent: String,\n  key: String,\n) -&gt; String\n Extract a value from a JSON string\n by specifying the parent and key.\nSynonyms:\nglee.extract_value_from_json\nglee extract_value_from_json","url":"glee.html#extract_value_from_json"},{"doc":"glee","title":"parse_json_bool","content":"pub fn parse_json_bool(\n  json: String,\n  field: String,\n) -&gt; Result(Bool, String)\n Parse a JSON string and return\n the boolean value of a given field.\nSynonyms:\nglee.parse_json_bool\nglee parse_json_bool","url":"glee.html#parse_json_bool"},{"doc":"glee","title":"parse_json_float","content":"pub fn parse_json_float(\n  json: String,\n  field: String,\n) -&gt; Result(Float, String)\n Parse a JSON string and return\n the float value of a given field.\nSynonyms:\nglee.parse_json_float\nglee parse_json_float","url":"glee.html#parse_json_float"},{"doc":"glee","title":"parse_json_int","content":"pub fn parse_json_int(\n  json: String,\n  field: String,\n) -&gt; Result(Int, String)\n Parse a JSON string and return\n the int value of a given field.\nSynonyms:\nglee.parse_json_int\nglee parse_json_int","url":"glee.html#parse_json_int"},{"doc":"glee","title":"parse_json_string","content":"pub fn parse_json_string(\n  json: String,\n  field: String,\n) -&gt; Result(String, String)\n Parse a JSON string and return\n the string value of a given field.\nSynonyms:\nglee.parse_json_string\nglee parse_json_string","url":"glee.html#parse_json_string"},{"doc":"glee","title":"glee","content":" Glee\n A simple way to parse JSON without\n having to implement the JSON module.\n +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n This is my first time using Gleam, so\n I&#39;m sure there are some things that\n could be done better.","url":"glee.html"}]);